/*
 *  $Id: gwyapp.h 23212 2021-03-11 16:25:12Z yeti-dn $
 *  Copyright (C) 2003-2013 David Necas (Yeti), Petr Klapetek.
 *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#ifndef __GWY_APP_GWYAPP_H__
#define __GWY_APP_GWYAPP_H__

#include <app/gwyapptypes.h>

#include <app/app.h>
#include <app/data-browser.h>
#include <app/datachooser.h>
#include <app/dialog.h>
#include <app/file.h>
#include <app/filelist.h>
#include <app/funcuse.h>
#include <app/glmaterial-editor.h>
#include <app/gradient-editor.h>
#include <app/gwytool.h>
#include <app/gwyplaintool.h>
#include <app/help.h>
#include <app/log.h>
#include <app/logging.h>
#include <app/menu.h>
#include <app/meta.h>
#include <app/param-def.h>
#include <app/params.h>
#include <app/param-table.h>
#include <app/resource-editor.h>
#include <app/gwyresultsexport.h>
#include <app/settings.h>
#include <app/undo.h>
#include <app/validate.h>
#include <app/wait.h>

#endif /* __GWY_APP_GWYAPP_H__ */

/* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
